==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/circular/beans/CircularDependentScopedBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.circular.beans;

import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.apache.webbeans.test.component.event.normal.Transactional;

@Dependent
public class CircularDependentScopedBean implements Serializable
{
    @Inject CircularApplicationScopedBean app;
    
    public static boolean success = false;
    
    
    @Transactional
    public void hello()
    {
        // do nothing
    }

    public void callAppScoped()
    {
        app.hello();
    }


    @PostConstruct
    public void postConstruct()
    {
        // removed! This is not allowed in JSR-299 according to mbg because it causes a 
        // cyclic reference in the creation of the beans! 
        // app.hello();
        success = true;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/injection/circular/beans/CircularDependentScopedBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.injection.circular.beans;

import java.io.Serializable;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.Dependent;
import jakarta.inject.Inject;

import org.apache.webbeans.test.component.event.normal.Transactional;

@Dependent
public class CircularDependentScopedBean implements Serializable
{
    @Inject CircularApplicationScopedBean app;
    
    public static boolean success = false;
    
    
    @Transactional
    public void hello()
    {
        // do nothing
    }

    public void callAppScoped()
    {
        app.hello();
    }


    @PostConstruct
    public void postConstruct()
    {
        // removed! This is not allowed in JSR-299 according to mbg because it causes a 
        // cyclic reference in the creation of the beans! 
        // app.hello();
        success = true;
    }
}
